<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Command\Infrastructure\Model;

use Core\Command\Domain\Model\CommandType;

final class CommandTypeConverter
{
    /**
     * @param CommandType $commandType
     *
     * @return int
     */
    public static function toInt(CommandType $commandType): int
    {
        return match ($commandType) {
            CommandType::Notification => 1,
            CommandType::Check => 2,
            CommandType::Miscellaneous => 3,
            CommandType::Discovery => 4,
        };
    }

    /**
     * @param int $commandType
     *
     * @throws \RangeException
     *
     * @return CommandType
     */
    public static function fromInt(int $commandType): CommandType
    {
        return match ($commandType) {
            1 => CommandType::Notification,
            2 => CommandType::Check,
            3 => CommandType::Miscellaneous,
            4 => CommandType::Discovery,
            default => throw new \RangeException('Command type must be between 1 and 4'),
        };
    }
}
